@@ -193,6 +193,7 @@
 #define HAVE_MEMFD_CREATE 1
 #define HAVE_POSIX_FALLOCATE 1
 #define HAVE_SIGACTION 1
+#define HAVE_SIGTIMEDWAIT 1
 #define HAVE_SA_SIGACTION 1
 #define HAVE_SETJMP 1
 #define HAVE_NANOSLEEP 1
@@ -241,7 +242,7 @@
 #define HAVE_IMMINTRIN_H 1
 #endif
 
-/* #undef HAVE_LIBUDEV_H */
+#define HAVE_LIBUDEV_H 1
 /* #undef HAVE_LIBSAMPLERATE_H */
 #define HAVE_LIBDECOR_H 1
 
@@ -307,7 +308,7 @@
 /* #undef SDL_AUDIO_DRIVER_FUSIONSOUND */
 /* #undef SDL_AUDIO_DRIVER_FUSIONSOUND_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_HAIKU */
-/* #undef SDL_AUDIO_DRIVER_JACK */
+#define SDL_AUDIO_DRIVER_JACK 1
 /* #undef SDL_AUDIO_DRIVER_JACK_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_NAS */
 /* #undef SDL_AUDIO_DRIVER_NAS_DYNAMIC */
@@ -316,7 +317,7 @@
 /* #undef SDL_AUDIO_DRIVER_PAUDIO */
 #define SDL_AUDIO_DRIVER_PIPEWIRE 1
 /* #undef SDL_AUDIO_DRIVER_PIPEWIRE_DYNAMIC */
-/* #undef SDL_AUDIO_DRIVER_PULSEAUDIO */
+#define SDL_AUDIO_DRIVER_PULSEAUDIO 1
 /* #undef SDL_AUDIO_DRIVER_PULSEAUDIO_DYNAMIC */
 /* #undef SDL_AUDIO_DRIVER_QSA */
 /* #undef SDL_AUDIO_DRIVER_SNDIO */
@@ -362,7 +363,7 @@
 /* #undef SDL_HAPTIC_XINPUT */
 /* #undef SDL_HAPTIC_ANDROID */
 /* #undef SDL_LIBUSB_DYNAMIC */
-/* #undef SDL_UDEV_DYNAMIC */
+#define SDL_UDEV_DYNAMIC "libudev.so.1"
 
 /* Enable various sensor drivers */
 /* #undef SDL_SENSOR_ANDROID */
